import React from 'react'
import { FluidType } from 'enum/fluid.enum'
import Tab, { TabProps } from '@material-ui/core/Tab'
import { withStyles } from '@material-ui/core/styles'

const TabBase = withStyles({
  root: {
    textTransform: 'none',
    minHeight: '36px',
  },
  selected: {
    background: 'var(--multiColorRadialGradient)',
    backgroundClip: 'text',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
  },
})(Tab)

const TabElec = withStyles({
  selected: {
    background: 'var(--elecColorRadialGradient)',
    backgroundClip: 'text',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
  },
})(TabBase)

const TabWater = withStyles({
  selected: {
    background: 'var(--waterColorRadialGradient)',
    backgroundClip: 'text',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
  },
})(TabBase)

const TabGas = withStyles({
  selected: {
    background: 'var(--gasColorRadialGradient)',
    backgroundClip: 'text',
    WebkitBackgroundClip: 'text',
    WebkitTextFillColor: 'transparent',
  },
})(TabBase)

interface StyledTabProps extends TabProps {
  fluidTypes: FluidType[]
  multiFluid: boolean
}

const StyledTab: React.ComponentType<StyledTabProps> = ({
  fluidTypes,
  multiFluid,
  ...props
}: StyledTabProps) => {
  if (multiFluid) {
    return <TabBase {...props}>{props.children}</TabBase>
  } else if (fluidTypes.length === 1) {
    switch (fluidTypes[0]) {
      case FluidType.ELECTRICITY:
        return <TabElec {...props}>{props.children}</TabElec>
      case FluidType.WATER:
        return <TabWater {...props}>{props.children}</TabWater>
      case FluidType.GAS:
        return <TabGas {...props}>{props.children}</TabGas>
    }
  }
  return <TabBase {...props}>{props.children}</TabBase>
}

export default StyledTab
