import React from 'react'
import { FluidType } from 'enum/fluid.enum'
import Tabs, { TabsProps } from '@material-ui/core/Tabs'
import { withStyles } from '@material-ui/core/styles'

const TabsBase = withStyles({
  root: {
    minHeight: '36px',
  },
  indicator: {
    '&:before': {
      content: '""',
      position: 'absolute',
      bottom: '0',
      width: 'inherit',
      opacity: '0.4',
      height: '6px',
      borderRadius: '50% 50% 0 0',
      filter: 'blur(8px)',
    },
  },
})(Tabs)

const TabsMulti = withStyles({
  indicator: {
    backgroundColor: 'var(--multiColor)',
    '&:before': {
      background: 'var(--multiColorRadialGradientTrans)',
    },
  },
})(TabsBase)

const TabsElec = withStyles({
  indicator: {
    backgroundColor: 'var(--elecColor)',
    '&:before': {
      background: 'var(--elecColorRadialGradientTrans)',
    },
  },
})(TabsBase)

const TabsWater = withStyles({
  indicator: {
    backgroundColor: 'var(--waterColor)',
    '&:before': {
      background: 'var(--waterColorRadialGradientTrans)',
    },
  },
})(TabsBase)

const TabsGas = withStyles({
  indicator: {
    backgroundColor: 'var(--gasColor)',
    '&:before': {
      background: 'var(--gasColorRadialGradientTrans)',
    },
  },
})(TabsBase)

interface StyledTabsProps extends TabsProps {
  fluidTypes: FluidType[]
  multiFluid: boolean
}

const StyledTabs: React.ComponentType<StyledTabsProps> = ({
  fluidTypes,
  multiFluid,
  ...props
}: StyledTabsProps) => {
  if (multiFluid) {
    return <TabsMulti {...props}>{props.children}</TabsMulti>
  } else if (fluidTypes.length === 1) {
    switch (fluidTypes[0]) {
      case FluidType.ELECTRICITY:
        return <TabsElec {...props}>{props.children}</TabsElec>
      case FluidType.WATER:
        return <TabsWater {...props}>{props.children}</TabsWater>
      case FluidType.GAS:
        return <TabsGas {...props}>{props.children}</TabsGas>
    }
  }
  return <TabsMulti {...props}>{props.children}</TabsMulti>
}

export default StyledTabs
